/* -*-  Mode:java; c-basic-offset:4; tab-width:4; indent-tabs-mode:nil -*- */
/*
 * ICMPTrainRecordReader.java
 *
 * Copyright (C) 2007-2009 by USC/ISI
 * $Id: ICMPTrainInputFormat.java 6409 2009-11-24 23:11:11Z yuri $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 */

package edu.isi.hadoop.icmptrain;

import java.io.*;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.*;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.io.compress.*;
import org.apache.hadoop.mapred.FileInputFormat;
import org.apache.hadoop.mapred.FileSplit;
import org.apache.hadoop.mapred.InputSplit;
import org.apache.hadoop.mapred.JobConf;
import org.apache.hadoop.mapred.JobConfigurable;
import org.apache.hadoop.mapred.RecordReader;
import org.apache.hadoop.mapred.Reporter;

/**
 * This class can serve as input format (option 
 * <tt>-inputformat edu.isi.hadoop.icmptrain.ICMPTrainInputFormat</tt> to Hadoop streaming)
 * for reading LANDER icmptrain data files. See {@link ICMPTrainRecordReader} for details.
 */
public class ICMPTrainInputFormat extends FileInputFormat<Text, Text>
    implements JobConfigurable 
{
    
    private CompressionCodecFactory compressionCodecs = null;
    private Configuration conf = new Configuration();
    
    public void configure(JobConf conf) {
        compressionCodecs = new CompressionCodecFactory(conf);
        this.conf=conf;
    }

    protected boolean isSplitable(FileSystem fs, Path file) {
        final CompressionCodec codec = compressionCodecs.getCodec(file);
        if (null == codec) {
            return true;
        }

        return codec instanceof SplittableCompressionCodec;
    }

  
    /**
     * @param genericSplit   Input split
     * @param job            Job configuration
     * @param reporter       reporter
     * @return               {@link ICMPTrainRecordReader}
     * @throws IOException   On input file/parse error
     */
    public RecordReader<Text, Text> getRecordReader(
                                                    InputSplit genericSplit, JobConf job,
                                                    Reporter reporter)
        throws IOException {
        
        reporter.setStatus(genericSplit.toString());
        return new edu.isi.hadoop.icmptrain.ICMPTrainRecordReader(job, (FileSplit) genericSplit);
    }
}
